#include "MotorControl.h"
#include "Logger.h"
#include <driver/ledc.h>

#define MOTOR_PIN1 15  // vorne links
#define MOTOR_PIN2 22  // hinten links
#define MOTOR_PIN3 13  // vorne rechts
#define MOTOR_PIN4 32  // hinten rechts

// PWM-Einstellungen
static const int pwmChannel1 = 0;
static const int pwmChannel2 = 1;
static const int pwmChannel3 = 2;
static const int pwmChannel4 = 3;
static const int pwmFrequency = 5000;
static const int pwmResolution = 8;

void MotorControl::init() {
  // PWM-Kanäle einrichten
  ledcSetup(pwmChannel1, pwmFrequency, pwmResolution);
  ledcSetup(pwmChannel2, pwmFrequency, pwmResolution);
  ledcSetup(pwmChannel3, pwmFrequency, pwmResolution);
  ledcSetup(pwmChannel4, pwmFrequency, pwmResolution);
  
  ledcAttachPin(MOTOR_PIN1, pwmChannel1);
  ledcAttachPin(MOTOR_PIN2, pwmChannel2);
  ledcAttachPin(MOTOR_PIN3, pwmChannel3);
  ledcAttachPin(MOTOR_PIN4, pwmChannel4);
  
  Logger::log("MotorControl initialized");
}

void MotorControl::stopMotors() {
  ledcWrite(pwmChannel1, 0);
  ledcWrite(pwmChannel2, 0);
  ledcWrite(pwmChannel3, 0);
  ledcWrite(pwmChannel4, 0);
  Logger::log("🚨 Motors stopped!", LOG_WARN);
}

void MotorControl::updateMotorSpeeds(int motorSpeed15, int motorSpeed22, int motorSpeed13, int motorSpeed32) {
  ledcWrite(pwmChannel1, motorSpeed15);
  ledcWrite(pwmChannel2, motorSpeed22);
  ledcWrite(pwmChannel3, motorSpeed13);
  ledcWrite(pwmChannel4, motorSpeed32);
  Logger::log("Motor speeds updated: Motor1: " + String(motorSpeed15) +
              ", Motor2: " + String(motorSpeed22) +
              ", Motor3: " + String(motorSpeed13) +
              ", Motor4: " + String(motorSpeed32));
}
