#include "PIDController.h"

PIDController::PIDController(double kp, double ki, double kd)
  : Kp(kp), Ki(ki), Kd(kd), integral(0.0), lastError(0.0) {}

double PIDController::compute(double setpoint, double measured, double dt) {
  double error = setpoint - measured;
  integral += error * dt;
  double derivative = (error - lastError) / dt;
  lastError = error;
  return Kp * error + Ki * integral + Kd * derivative;
}

void PIDController::reset() {
  integral = 0.0;
  lastError = 0.0;
}
