#include <Arduino.h>
#include "Logger.h"
#include "MotorControl.h"
#include "Gyro.h"
#include "GamepadHandler.h"
#include "PersistenceImpl.h"

// FreeRTOS-Task-Handles
TaskHandle_t gamepadTaskHandle = NULL;
TaskHandle_t failsafeTaskHandle = NULL;

const unsigned long failsafeTimeout = 20000; // 20 Sekunden

// Task für die Gamepad-Verarbeitung
void gamepadTask(void * parameter) {
  for(;;) {
    GamepadHandler::process();
    vTaskDelay(10 / portTICK_PERIOD_MS);
  }
}

// Task für Failsafe-Überwachung
void failsafeTask(void * parameter) {
  for(;;) {
    if (millis() - GamepadHandler::getLastUpdateTime() > failsafeTimeout) {
      Logger::log("⏳ Failsafe activated, stopping motors!", LOG_WARN);
      MotorControl::stopMotors();
    }
    vTaskDelay(10 / portTICK_PERIOD_MS);
  }
}

void setup() {
  Logger::init(921600);
  Logger::log("Setup start");
  
  MotorControl::init();
  
  if (!Gyro::init()) {
    while(1) { vTaskDelay(10 / portTICK_PERIOD_MS); }
  }
  Gyro::calibrate();
  
  GamepadHandler::init();
  
  // Beispielhafte Persistenznutzung
  PersistenceImpl persistence;
  persistence.saveConfig("exampleKey", "exampleValue");
  
  // Erstelle parallele Tasks
  xTaskCreatePinnedToCore(
    gamepadTask,
    "Gamepad Task",
    4096,
    NULL,
    1,
    &gamepadTaskHandle,
    1
  );
  
  xTaskCreatePinnedToCore(
    failsafeTask,
    "Failsafe Task",
    2048,
    NULL,
    1,
    &failsafeTaskHandle,
    1
  );
  
  Logger::log("Setup complete");
}

void loop() {
  // Hauptloop bleibt weitgehend leer, da die Tasks die Verarbeitung übernehmen
  vTaskDelay(1000 / portTICK_PERIOD_MS);
}
