# 🚁 Drohnenprojekt  
---
## 📌 Projektübersicht  

Die Idee, eine eigene Minidrohne zu bauen, entstand aus der Kombination von Neugier und dem Wunsch, technische Fähigkeiten in verschiedenen Bereichen wie Mechanik, Elektronik und Programmierung praktisch anzuwenden. Da uns Softwareprojekte in letzter Zeit häufiger begegnet sind, wollten wir uns einer Hardware-Herausforderung widmen, die sowohl spannend als auch lehrreich ist. Die Entwicklung einer Minidrohne bietet viele interessante Aspekte: Von der Konstruktion des Rahmens über die Auswahl und Integration der Komponenten bis hin zur Entwicklung der Flugsteuerungssoftware.  

---

## 🔧 Programmiercode in Arduino ausführbar machen  

### 📋 Voraussetzungen  

- **Mikrocontroller:** *ESP32 - Wroom32*  
- **Entwicklungsumgebung:** [ArduinoIDE](https://www.arduino.cc/en/software) oder *PlatformIO*  
- **USB-Treiber:** [CP210x USB-Treiber](https://www.silabs.com/developer-tools/usb-to-uart-bridge-vcp-drivers?tab=downloads)
- **Controller:** *Bluetooth Gaming Controller (Xbox, Playstation, Nintendo etc.)*   

### 💻 Einrichtung  

1. **Repository klonen**  
   ```bash
   git clone https://gitlab.mi.hdm-stuttgart.de/mh370/drohnenprojekt.git
   cd drohnenprojekt
   ```

2. **Arduino-Sketch Dateiöffnen**  
   *    In der main Branch zu -->
   *    drohnenprojekt/ArduinoSketch/DroneSketches/drone_Sketch-final.ino   

3. **Benötigte Bibliotheken installieren**  
   * Bluepad32 
   * Adafruit_MPU6050 
   * Adafruit_Sensor 
   * WiFi 
   * AsyncTCP 
   * ESPAsyncWebServer 

   Können über die ArduinoIDE Bibliotheksverwalter installiert werden

4. **Code auf den Mikrocontroller hochladen**  
   *Platzhalter für Anleitung zum Hochladen des Codes (z. B. in der Arduino IDE oder über die CLI)*  

---

## 🧪 Tests   

Im Sketch sind mehrere Tests direkt implementiert, die manuell gestartet werden können, wenn der Microcontroller mit einem Rechner verbunden ist auf welchem die Arduino IDE läuft. Die Ausgabe erfolgt über den seriellen Monitor
   
   - Unittest für die Controllerautentisierung über eine simulierte falsche MAC-Adresse und eine richtige MAC-Adresse (start über Eingabe "t")
   - Integrationstets für die Motorsteuerung, bei welchem die Motoren testweise für 2 sekunden angesteuert werden. (start über Eingabe "m")
   - Funktionstest des Failsafe-Mechanismus bei welchem die Zeitüberschreitung seit der letzten Controllereingabe simuliert wird und die Motoren somit gestoppt werden. (start über Eingabe "f" )

Nach dem jeweiligen Testdurchlauf wird automatisch wieder in den normalen Drohnenbetrieb gewechselt.

---

## 🤝 Zusammenarbeit  

🔗 **Team-Mitglieder einladen:**  
[GitLab Mitgliederverwaltung](https://docs.gitlab.com/ee/user/project/members/)  

🔀 **Merge Requests erstellen:**  
[Anleitung zu Merge Requests](https://docs.gitlab.com/ee/user/project/merge_requests/creating_merge_requests.html)  

📊 **CI/CD für automatische Tests & Builds:**  
[GitLab CI/CD](https://docs.gitlab.com/ee/ci/quick_start/index.html)  

---


## 💡 Autoren  

👨‍💻 **Projektteam:**  
- **Martin Herdt** – Softwareentwicklung  
- **Fabio Brandner** – Hardware-Integration  

📩 **Kontakt:** Bei Fragen oder Anregungen bitte eine Nachricht an das Team senden.  

---


