#include "Gyro.h"
#include "Logger.h"
#include <Wire.h>
#include <math.h>

static Adafruit_MPU6050 mpu;  // MPU6050-Instanz
static double gyroPitchOffset = 0.0;
static double gyroRollOffset  = 0.0;

bool Gyro::init() {
  Wire.begin(14, 5); // SDA, SCL
  if (!mpu.begin()) {
    Logger::log("❌ Failed to find MPU6050 chip", LOG_ERROR);
    return false;
  }
  mpu.setAccelerometerRange(MPU6050_RANGE_8_G);
  mpu.setGyroRange(MPU6050_RANGE_500_DEG);
  mpu.setFilterBandwidth(MPU6050_BAND_21_HZ);
  Logger::log("✅ MPU6050 found and initialized!");
  return true;
}

void Gyro::calibrate() {
  const int numSamples = 100;
  double sumPitch = 0.0, sumRoll = 0.0;
  sensors_event_t a, g, temp;
  for (int i = 0; i < numSamples; i++) {
    mpu.getEvent(&a, &g, &temp);
    double rawPitch = atan2(a.acceleration.x, sqrt(a.acceleration.y * a.acceleration.y + a.acceleration.z * a.acceleration.z)) * 57.2958;
    double rawRoll  = atan2(a.acceleration.y, sqrt(a.acceleration.x * a.acceleration.x + a.acceleration.z * a.acceleration.z)) * 57.2958;
    sumPitch += rawPitch;
    sumRoll  += rawRoll;
    delay(10);
  }
  gyroPitchOffset = sumPitch / numSamples;
  gyroRollOffset  = sumRoll / numSamples;
  Logger::log("Gyro calibrated: Pitch Offset = " + String(gyroPitchOffset, 2) +
              "°, Roll Offset = " + String(gyroRollOffset, 2) + "°");
}

void Gyro::getCorrectedAngles(double &pitch, double &roll) {
  sensors_event_t a, g, temp;
  mpu.getEvent(&a, &g, &temp);
  double rawPitch = atan2(a.acceleration.x, sqrt(a.acceleration.y * a.acceleration.y + a.acceleration.z * a.acceleration.z)) * 57.2958;
  double rawRoll  = atan2(a.acceleration.y, sqrt(a.acceleration.x * a.acceleration.x + a.acceleration.z * a.acceleration.z)) * 57.2958;
  pitch = rawPitch - gyroPitchOffset;
  roll  = rawRoll  - gyroRollOffset;
}
