#include <Wire.h>
#include <Adafruit_MPU6050.h>
#include <Adafruit_Sensor.h>

#define SDA_PIN 14   // I2C SDA
#define SCL_PIN 5    // I2C SCL
#define INT_PIN 16   // INT-Pin

Adafruit_MPU6050 mpu;
volatile bool motionDetected = false;

// Interrupt-Handler für Bewegung
void IRAM_ATTR mpuInterrupt() {
  motionDetected = true;
}

void setup() {
  Serial.begin(115200);
  Serial.println("🔧 Starte MPU6050-Test...");

  // I2C mit eigenen Pins starten
  Wire.begin(SDA_PIN, SCL_PIN);

  // MPU6050 initialisieren
  if (!mpu.begin()) {
    Serial.println("❌ MPU6050 nicht gefunden!");
    while (1); // Endlosschleife bei Fehler
  }
  Serial.println("✅ MPU6050 erfolgreich verbunden!");

  // Sensor-Konfiguration
  mpu.setAccelerometerRange(MPU6050_RANGE_2_G);
  mpu.setGyroRange(MPU6050_RANGE_250_DEG);
  mpu.setFilterBandwidth(MPU6050_BAND_21_HZ);

  // Interrupt-Pin konfigurieren
  pinMode(INT_PIN, INPUT_PULLUP);
  attachInterrupt(digitalPinToInterrupt(INT_PIN), mpuInterrupt, RISING);

  Serial.println("🔄 Warte auf Bewegung...");
}

void loop() {
  // Falls Bewegung erkannt wurde
  if (motionDetected) {
    Serial.println("⚡ Bewegung erkannt! ⚡");
    motionDetected = false;
  }

  // Sensordaten auslesen
  sensors_event_t accel, gyro, temp;
  mpu.getEvent(&accel, &gyro, &temp);

  // Beschleunigung
  Serial.print("📌 Beschleunigung (m/s²): X=");
  Serial.print(accel.acceleration.x);
  Serial.print(" Y=");
  Serial.print(accel.acceleration.y);
  Serial.print(" Z=");
  Serial.println(accel.acceleration.z);

  // Gyroskop-Werte
  Serial.print("🎯 Gyroskop (°/s): X=");
  Serial.print(gyro.gyro.x);
  Serial.print(" Y=");
  Serial.print(gyro.gyro.y);
  Serial.print(" Z=");
  Serial.println(gyro.gyro.z);

  // Temperatur
  Serial.print("🌡️ Temperatur (°C): ");
  Serial.println(temp.temperature);

  Serial.println("====================================");
  delay(500);
}
